/* From wpobject.h */
      /*  Open views for the wpOpen() method */

      #define OPEN_UNKNOWN      -1
      #define OPEN_DEFAULT       0
      #define OPEN_CONTENTS      1
      #define OPEN_SETTINGS      2
      #define OPEN_HELP          3
      #define OPEN_RUNNING       4
      #define OPEN_PROMPTDLG     5
      #define OPEN_PALETTE       121                                   /*SPLIT*/
      #define OPEN_USER          0x6500

/* From wpfolder.h */
      #define OPEN_TREE          101
      #define OPEN_DETAILS       102

/* From wpdisk.h */
    #define OPEN_AUTO            120

/* From wppower.h */
#define OPEN_STATUS  131
    #define OPEN_BATTERY 132
